export = exporter;
/**
 * @param {string | CID} path
 * @param {IPLDResolver} ipld
 * @param {ExporterOptions} [options]
 */
declare function exporter(path: string | CID, ipld: IPLDResolver, options?: ExporterOptions | undefined): Promise<UnixFSEntry>;
declare namespace exporter {
    export { walkPath as path, recursive, UnixFS, DAGNode, UnixFSFile, UnixFSDirectory, ObjectNode, RawNode, IdentityNode, UnixFSEntry, IPLDResolver, ExporterOptions };
}
import CID = require("cids");
type IPLDResolver = {
    get: (cid: CID, options?: any) => Promise<any>;
    put: (node: any, codec: number, options?: any) => Promise<CID>;
};
type ExporterOptions = {
    offset?: number | undefined;
    length?: number | undefined;
};
type UnixFSEntry = UnixFSFile | UnixFSDirectory | ObjectNode | RawNode | IdentityNode;
/**
 * @param {string | CID} path
 * @param {IPLDResolver} ipld
 * @param {ExporterOptions} [options]
 */
declare function walkPath(path: string | CID, ipld: IPLDResolver, options?: ExporterOptions | undefined): AsyncGenerator<UnixFSEntry, void, unknown>;
/**
 * @param {string | CID} path
 * @param {IPLDResolver} ipld
 * @param {ExporterOptions} [options]
 */
declare function recursive(path: string | CID, ipld: IPLDResolver, options?: ExporterOptions | undefined): AsyncGenerator<UnixFSEntry, void, unknown>;
type UnixFS = import("ipfs-unixfs");
type DAGNode = import("ipld-dag-pb/src/dag-node/dagNode");
type UnixFSFile = {
    type: 'file';
    name: string;
    path: string;
    cid: CID;
    depth: number;
    unixfs: UnixFS;
    node: DAGNode;
    content: (options?: ExporterOptions | undefined) => AsyncIterable<Uint8Array>;
};
type UnixFSDirectory = {
    type: 'directory';
    name: string;
    path: string;
    cid: CID;
    depth: number;
    unixfs: UnixFS;
    node: DAGNode;
    content: (options?: ExporterOptions | undefined) => AsyncIterable<UnixFSEntry>;
};
type ObjectNode = {
    type: 'object';
    name: string;
    path: string;
    cid: CID;
    depth: number;
    node: any;
};
type RawNode = {
    type: 'raw';
    name: string;
    path: string;
    cid: CID;
    depth: number;
    node: Uint8Array;
    content: (options?: ExporterOptions | undefined) => AsyncIterable<Uint8Array>;
};
type IdentityNode = {
    type: 'identity';
    name: string;
    path: string;
    cid: CID;
    depth: number;
    node: Uint8Array;
    content: (options?: ExporterOptions | undefined) => AsyncIterable<Uint8Array>;
};
//# sourceMappingURL=index.d.ts.map